"""Fitting Mastery and Skill Plan generator."""

default_app_config = "mastery.apps.MasteryConfig"  # pylint: disable=invalid-name

__appname__ = "mastery"
__version__ = "0.2.1"
__title__ = "Fitting Mastery"
