# Generated by Django 4.2.23 on 2026-04-06 12:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('eve_sde', '0018_blueprintactivity_blueprintactivityproduct_and_more'),
        ('fittings', '0001_initialize'),
        ('memberaudit', '0020_add_new_roles'),
    ]

    operations = [
        migrations.CreateModel(
            name='DoctrineSkillSetGroupMap',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('doctrine', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='fittings.doctrine', verbose_name='doctrine')),
                ('skillset_group', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='memberaudit.skillsetgroup', verbose_name='skillset group')),
            ],
            options={
                'unique_together': {('doctrine_id', 'skillset_group_id')},
            },
        ),
        migrations.CreateModel(
            name='SdeVersion',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('build_number', models.BigIntegerField()),
                ('release_date', models.DateTimeField()),
                ('imported_at', models.DateTimeField(auto_now_add=True)),
                ('is_active', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='ShipMastery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('level', models.IntegerField()),
                ('ship_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eve_sde.itemtype')),
            ],
        ),
        migrations.CreateModel(
            name='DoctrineSkillSnapshot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('doctrine_name', models.CharField(max_length=255, verbose_name='doctrine name')),
                ('fitting_name', models.CharField(max_length=255, verbose_name='fitting name')),
                ('ship_name', models.CharField(max_length=255)),
                ('required_level', models.PositiveIntegerField(default=0, verbose_name='required level')),
                ('recommended_level', models.PositiveIntegerField(default=0, verbose_name='recommended level')),
                ('is_required', models.BooleanField(default=False)),
                ('is_recommended', models.BooleanField(default=False)),
                ('level_gap', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('doctrine', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='fittings.doctrine', verbose_name='doctrine')),
                ('fitting', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='fittings.fitting', verbose_name='fitting')),
                ('ship_type', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='eve_sde.itemtype', verbose_name='ship type')),
                ('skill_type', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='eve_sde.itemtype', verbose_name='skill type')),
            ],
        ),
        migrations.CreateModel(
            name='ShipMasteryCertificate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('certificate_id', models.IntegerField()),
                ('mastery', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mastery.shipmastery')),
            ],
            options={
                'indexes': [models.Index(fields=['certificate_id'], name='mastery_shi_certifi_daf3bf_idx')],
            },
        ),
        migrations.CreateModel(
            name='FittingSkillsetMap',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('doctrine_map', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='fittings', to='mastery.doctrineskillsetgroupmap', verbose_name='doctrine map')),
                ('fitting', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='fittings.fitting', verbose_name='fitting')),
                ('skillset', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='memberaudit.skillset', verbose_name='skillset')),
            ],
            options={
                'unique_together': {('fitting_id', 'skillset_id')},
            },
        ),
        migrations.CreateModel(
            name='FittingSkillOverride',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_blacklisted', models.BooleanField(default=True)),
                ('fitting', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='fittings.fitting', verbose_name='fitting')),
                ('skill_type', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='eve_sde.itemtype', verbose_name='skill type')),
            ],
            options={
                'unique_together': {('fitting_id', 'skill_type_id')},
            },
        ),
        migrations.CreateModel(
            name='FittingSkillControl',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_blacklisted', models.BooleanField(default=False, verbose_name='is blacklisted')),
                ('is_suggested', models.BooleanField(default=False, verbose_name='is suggested')),
                ('reason', models.CharField(blank=True, max_length=255, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('fitting', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='fittings.fitting', verbose_name='fitting')),
                ('skill_type', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='eve_sde.itemtype', verbose_name='skill type')),
            ],
            options={
                'indexes': [models.Index(fields=['fitting_id'], name='mastery_fit_fitting_ad4699_idx')],
                'unique_together': {('fitting_id', 'skill_type_id')},
            },
        ),
        migrations.CreateModel(
            name='CertificateSkill',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('certificate_id', models.IntegerField()),
                ('level_basic', models.IntegerField(null=True)),
                ('level_standard', models.IntegerField(null=True)),
                ('level_improved', models.IntegerField(null=True)),
                ('level_advanced', models.IntegerField(null=True)),
                ('level_elite', models.IntegerField(null=True)),
                ('skill_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eve_sde.itemtype')),
            ],
            options={
                'indexes': [models.Index(fields=['certificate_id'], name='mastery_cer_certifi_ec93cb_idx')],
            },
        ),
    ]
