# Generated by Django 4.2.23 on 2026-04-28 09:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('mastery', '0012_masterydoctrinereadinessfilter_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='masterydoctrinereadinessfilter',
            name='alliances',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these alliances are considered.', related_name='mastery_doctrine_filters', to='eveonline.eveallianceinfo', verbose_name='alliances'),
        ),
        migrations.AddField(
            model_name='masterydoctrinereadinessfilter',
            name='corporations',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these corporations are considered.', related_name='mastery_doctrine_filters', to='eveonline.evecorporationinfo', verbose_name='corporations'),
        ),
        migrations.AddField(
            model_name='masteryfittingelitefilter',
            name='alliances',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these alliances are considered.', related_name='mastery_elite_filters', to='eveonline.eveallianceinfo', verbose_name='alliances'),
        ),
        migrations.AddField(
            model_name='masteryfittingelitefilter',
            name='corporations',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these corporations are considered.', related_name='mastery_elite_filters', to='eveonline.evecorporationinfo', verbose_name='corporations'),
        ),
        migrations.AddField(
            model_name='masteryfittingprogressfilter',
            name='alliances',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these alliances are considered.', related_name='mastery_progress_filters', to='eveonline.eveallianceinfo', verbose_name='alliances'),
        ),
        migrations.AddField(
            model_name='masteryfittingprogressfilter',
            name='corporations',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these corporations are considered.', related_name='mastery_progress_filters', to='eveonline.evecorporationinfo', verbose_name='corporations'),
        ),
        migrations.AddField(
            model_name='masteryfittingstatusfilter',
            name='alliances',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these alliances are considered.', related_name='mastery_status_filters', to='eveonline.eveallianceinfo', verbose_name='alliances'),
        ),
        migrations.AddField(
            model_name='masteryfittingstatusfilter',
            name='corporations',
            field=models.ManyToManyField(blank=True, help_text='Optional scope. If set, only characters in these corporations are considered.', related_name='mastery_status_filters', to='eveonline.evecorporationinfo', verbose_name='corporations'),
        ),
    ]
