# Generated by Django 4.2.23 on 2026-04-08 14:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mastery', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrineskillsetgroupmap',
            name='default_mastery_level',
            field=models.PositiveIntegerField(default=4, verbose_name='default mastery level'),
        ),
        migrations.AddField(
            model_name='fittingskillsetmap',
            name='mastery_level',
            field=models.PositiveIntegerField(default=4, verbose_name='mastery level'),
        ),
    ]
