{% for message in messages %}
<div class="alert alert-{{ message.level|default:'success' }} alert-dismissible fade show shadow-sm mb-0" role="alert">
    {{ message.text }}
    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
</div>
{% endfor %}

