{% load i18n %}

<th class="text-success">
    {% translate "Elite" %}{% if include_chars_suffix %} ({% translate "chars" %}){% endif %}
    {% if include_tooltips %}
    <span class="fas fa-question-circle small text-muted" data-bs-tooltip="aa-mastery" data-bs-title="{% blocktranslate with pct=status_thresholds.elite_recommended %}Can fly and recommended >= {{ pct }}%{% endblocktranslate %}"></span>
    {% endif %}
</th>
<th class="text-primary">
    {% translate "Almost elite" %}{% if include_chars_suffix %} ({% translate "chars" %}){% endif %}
    {% if include_tooltips %}
    <span class="fas fa-question-circle small text-muted" data-bs-tooltip="aa-mastery" data-bs-title="{% blocktranslate with pct=status_thresholds.almost_elite_recommended %}Can fly and recommended > {{ pct }}%{% endblocktranslate %}"></span>
    {% endif %}
</th>
<th class="text-info">
    {% translate "Can fly" %}{% if include_chars_suffix %} ({% translate "chars" %}){% endif %}
    {% if include_tooltips %}
    <span class="fas fa-question-circle small text-muted" data-bs-tooltip="aa-mastery" data-bs-title="{% translate 'Meets all required skills' %}"></span>
    {% endif %}
</th>
<th class="text-warning">
    {% translate "Almost fit" %}{% if include_chars_suffix %} ({% translate "chars" %}){% endif %}
    {% if include_tooltips %}
    <span class="fas fa-question-circle small text-muted" data-bs-tooltip="aa-mastery" data-bs-title="{% blocktranslate with pct=status_thresholds.almost_fit_required %}Not flyable and required > {{ pct }}%{% endblocktranslate %}"></span>
    {% endif %}
</th>
<th class="text-danger">
    {% translate "Needs training" %}{% if include_chars_suffix %} ({% translate "chars" %}){% endif %}
    {% if include_tooltips %}
    <span class="fas fa-question-circle small text-muted" data-bs-tooltip="aa-mastery" data-bs-title="{% blocktranslate with pct=status_thresholds.almost_fit_required %}Not flyable and required <= {{ pct }}%{% endblocktranslate %}"></span>
    {% endif %}
</th>

